require 'fastcst/ui'
require 'fastcst/repo'


module Repository

    class UndoCommand < Command
        def initialize(argv)
            @directory = "."
        
            super(argv, [
               ["-t", "--test", "", :@test],
            ])
            @repo_dir = Repository.search
        end
    
        def validate
            valid? @repo_dir, "Could not find the repository directory"
            valid?((not @test), "The -t (test) option is not available yet")
            
            return @valid
        end
    
    
        def run
            repo = Repository.new @repo_dir
            rev_path = repo['Path']
            id = rev_path.pop
            cs_path, md = repo.find_changeset(id)
            
            if not File.exist?(File.join(cs_path, "undo.yaml"))
                UI.failure :constraint, "No undo.yaml file so there's no undo possible."
            elsif not File.exist?(File.join(cs_path, "undo.fcs"))
                UI.failure :constraint, "No undo.fcs file so there's no undo possible."
            elsif cs_path
                # get the undo revision and apply it to both directories
                journal_file = File.join(cs_path, "undo.yaml")
                data_file = File.join(cs_path, "undo.fcs")
                
                UI.start_finish("Applying undo revision for #{md['Revision']}") do
                    journal_in = Zlib::GzipReader.new(File.open(journal_file))
                    data_in = Zlib::GzipReader.new(File.open(data_file))
                    
                    ChangeSet.apply_changeset(journal_in, data_in, ".")
                end
                
                UI.start_finish("Applying undo revision to originals rirectory") do
                    journal_in = Zlib::GzipReader.new(File.open(journal_file))
                    data_in = Zlib::GzipReader.new(File.open(data_file))
                    
                    ChangeSet.apply_changeset(journal_in, data_in, repo.originals_dir)
                end
                
                # now update the path to have the new 
                repo['Path'] = rev_path
            else
                UI.failure :constraint, "It appears that you have a revision listed in your path with a missing directory."
            end
        end
    end
end 
